@@ -3,7 +3,7 @@ package Specio::Constraint::Role::Interface;
 use strict;
 use warnings;
 
-our $VERSION = '0.36';
+our $VERSION = '0.43';
 
 use Carp qw( confess );
 use Eval::Closure qw( eval_closure );
@@ -434,21 +434,7 @@ sub _build_subification {
     my $self = shift;
 
     if ( defined &Sub::Quote::quote_sub && $self->can_be_inlined ) {
-        my $inline = $self->inline_check('$_[0]');
-        $inline .= ' or ';
-
-        my %env = (
-            '$message_generator' => \( $self->_message_generator ),
-            '$type'              => \$self,
-        );
-
-        $inline .= $self->_inline_throw_exception(
-            '$_[0]',
-            '$message_generator',
-            '$type',
-        );
-
-        return Sub::Quote::quote_sub( $inline, \%env );
+        return Sub::Quote::quote_sub( $self->inline_assert('$_[0]') );
     }
     else {
         return sub { $self->validate_or_die( $_[0] ) };
@@ -632,7 +618,7 @@ Specio::Constraint::Role::Interface - The interface all type constraints should
 
 =head1 VERSION
 
-version 0.36
+version 0.43
 
 =head1 DESCRIPTION
 
@@ -669,7 +655,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 - 2017 by Dave Rolsky.
+This software is Copyright (c) 2012 - 2018 by Dave Rolsky.
 
 This is free software, licensed under:
 
